@@ -24,7 +24,7 @@
 /**************************************** Common constants */
 
 #ifndef VERSION
-#define VERSION "4.17"
+#define VERSION "undefined"
 #endif
 
 #ifdef OPTIMIZE_SCALABILITY
@@ -36,9 +36,6 @@
 /* I/O buffer size */
 #define BUFFSIZE        2048
 
-/* Length of strings (including the terminating '\0' character) */
-#define STRLEN          128
-
 #else /* OPTIMIZE_SCALABILITY */
 
 /* CPU stack size */
@@ -47,11 +44,12 @@
 /* I/O buffer size */
 #define BUFFSIZE        16384
 
-/* Length of strings (including the terminating '\0' character) */
-#define STRLEN          256
-
 #endif /* OPTIMIZE_SCALABILITY */
 
+/* Length of strings (including the terminating '\0' character) */
+/* It can't be lower than 256 bytes or NTLM authentication will break */
+#define STRLEN          256
+
 /* IP address and TCP port textual representation length */
 #define IPLEN           128
 
@@ -315,6 +313,8 @@ extern char *sys_errlist[];
 #include <openssl/err.h>
 #include <openssl/crypto.h> /* for CRYPTO_* and SSLeay_version */
 #include <openssl/rand.h>
+#include <openssl/md4.h>
+#include <openssl/des.h>
 #ifdef HAVE_OSSL_ENGINE_H
 #include <openssl/engine.h>
 #endif
@@ -326,6 +326,8 @@ extern char *sys_errlist[];
 #include <ssl.h>
 #include <err.h>
 #include <crypto.h> /* for CRYPTO_* and SSLeay_version */
+#include <md4.h>
+#include <des.h>
 #endif /* HAVE_OPENSSL */
 
 /**************************************** Other defines */
